<?php
namespace Teknisa\PLA\Modules\Relatorio\Services;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Pla06300PesquisaDeConsumoDeProdutosService  {

	protected $crudService;
	protected $environment;
	protected $parameterBagColumns;
	protected $dataSourceManager;
	protected $connection;

	public function __construct($crudService, $environment, $dataSourceManager, $connection) {
		$this->crudService         		= $crudService;
		$this->environment       		  = $environment;
		$this->connection       		  = $connection;
		$this->dataSourceManager 		  = $dataSourceManager;
	}

	public function insereLista($row){
		$sql = "INSERT INTO LISTA
				   (NRLISTA, CDLISTA)
				   (SELECT DISTINCT :P_NRLISTA,
					     SERVICO.CDFILIAL || SERVICO.CDSERVFILI
					 FROM
					     SERVICO,FILIAL
					     INNER JOIN FILIOPER FO ON FO.NRORG = FILIAL.NRORG
					                               AND FO.CDFILIAL = FILIAL.CDFILIAL
					     LEFT JOIN FILGRUPFILI FG ON FILIAL.NRORG = FG.NRORG
					                                 AND FILIAL.CDFILIAL = FG.CDFILIAL
					 WHERE
					     FILIAL.NRORG = SERVICO.NRORG
					     AND FILIAL.CDFILIAL = SERVICO.CDFILIAL
					     AND SERVICO.NRORG =:P_NRORG
					     AND ( INSTR(:P_CDFILIAL,SERVICO.CDFILIAL) <> 0
					           OR :P_CDFILIAL = 'T' )
			             AND ( (:P_CDSERVFILI                     = 'T')
						    	OR (INSTR(:P_CDSERVFILI, SERVICO.CDSERVFILI) > 0))
					     AND FO.CDOPERADOR =:P_CDOPERADOR
					     AND (:P_CDGRUPFILI = FG.CDGRUPFILI
					          OR :P_CDGRUPFILI = 'T' ))";

		$servico = ($row['NMSERVICO'] == 'T') ?  'T' :  join("_",$row['NMSERVICO']);
		$filial = ($row['NMFILIAL'] == 'T') ?  'T' :  join("_",$row['NMFILIAL']);
		$grupgfili = isset($row['CDGRUPFILI']) ? ($row['CDGRUPFILI'] != "" ? $row['CDGRUPFILI'] : 'T' ) : 'T';
		
		$params = array(
		  'P_NRLISTA' => $row['P_NRLISTAPROD'],
	      'P_NRORG' => $row['NRORG'],
	      'P_CDFILIAL' =>$filial,
	      'P_CDOPERADOR' => $row['CDOPERADOR'],
	      'P_CDGRUPFILI' => $grupgfili,
	      'P_CDSERVFILI' => $servico
		);
		$query = $this->connection->prepare($sql);
    	$query->execute($params);
	}

	public function includeListaProd($row){
		$sql = "INSERT INTO LISTA
   					(NRLISTA, CDLISTA)
					(SELECT :P_NRLISTA, P.CDPRODUTO
						FROM PRODUTO P,
						  (SELECT MAX(CDNVPRODUTO) CDNVPRODUTO FROM PRODUTO) PR
						WHERE ((INSTR(:P_LISTAPROD, P.CDPRODUTO) > 0)
						  OR :P_LISTAPROD = 'T')
						AND (P.CDNVPRODUTO = PR.CDNVPRODUTO))";
		$list = ($row['NMPRODUTO'] == 'T') ?  'T' :  join("_",$row['NMPRODUTO']);
		$params = array(
		  'P_NRLISTA' => $row['P_NRLISTAPROD'],
      'P_LISTAPROD' =>$list
		);
		$query = $this->connection->prepare($sql);
    $query->execute($params);
	}

	public function callConsplan($row){
		$idprodutos = $row['P_CARDAPIO'].$row['P_FIXO'].$row['P_PERCAPITA'];

		$consplan = new StoredProcedure($this->connection, 'CONSPLAN_GERAL');
		$consplan->addParam(new Param('P_NRLISTA', Param::PARAM_INPUT, $row['P_NRLISTAPROD'], Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $row['P_DTINICIAL'], Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $row['P_DTFINAL'], Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_IDPRODUTOS', Param::PARAM_INPUT, $idprodutos, Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_IDSEPPRATO', Param::PARAM_INPUT, 'P', Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_PEACRESCIMO', Param::PARAM_INPUT, 0, Param::PARAM_TYPE_INT));
		$consplan->addParam(new Param('P_IDARREDOND', Param::PARAM_INPUT, 'N', Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_CDPRODUTOINI', Param::PARAM_INPUT, '0', Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_CDPRODUTOFIN', Param::PARAM_INPUT, 'zzzzzzzzzz', Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $this->environment->getCdOperador(), Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_NRCONSPLANTH', Param::PARAM_INPUT, 'GERANOVCOD', Param::PARAM_TYPE_STR));
		$consplan->addParam(new Param('P_NRCONSPLAN', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 10));
		return $consplan->execute();
	}

	public function deleteLista($row){
		$sql = "DELETE
  					FROM LISTA
 						WHERE NRLISTA = :P_NRLISTA";

		$params = array('P_NRLISTA' => $row['P_NRLISTAPROD']);
		$query = $this->connection->prepare($sql);
    $query->execute($params);
	}

	public function deleteConsplan($row) {
		$sql = "DELETE
  					FROM CONSPLAN
 						WHERE NRCONSPLAN = :P_NRCONSPLAN";
		$nrConsplan = $row['P_NRCONSPLAN'];
		$params = array('P_NRCONSPLAN' => $nrConsplan);
		$query = $this->connection->prepare($sql);
    $query->execute($params);
	}
}